searchData={"items":[{"type":"module","title":"Xav.Decoder","doc":"Audio/video decoder.","ref":"Xav.Decoder.html"},{"type":"function","title":"Xav.Decoder.decode/3","doc":"Decodes an audio/video frame.\n\nSome video frames are meant for decoder only and will not\ncontain actual video samples.\nSome audio frames might require more data to be converted\nto the desired output format.\nIn both cases, `:ok` term is returned and more data needs to be provided.","ref":"Xav.Decoder.html#decode/3"},{"type":"function","title":"Xav.Decoder.new/2","doc":"Creates a new decoder.\n\n`opts` can be used to specify desired output parameters.\n\nE.g. if you want to change audio samples format just pass:\n\n```elixir\n[out_format: :f32]\n```\n\nVideo frames are always returned in RGB format.\nThis setting cannot be changed.\n\nAudio samples are always in the packed form -\nsamples from different channels are interleaved in the same, single binary:\n\n```\n< >\n```\n\nAn alternative would be to return a list of binaries, where\neach binary represents different channel:\n\n```\n[\n  < >,\n  < >,\n  < >\n]\n```","ref":"Xav.Decoder.html#new/2"},{"type":"type","title":"Xav.Decoder.codec/0","doc":"Supported codecs.","ref":"Xav.Decoder.html#t:codec/0"},{"type":"type","title":"Xav.Decoder.opts/0","doc":"Opts that can be passed to `new/2`.","ref":"Xav.Decoder.html#t:opts/0"},{"type":"type","title":"Xav.Decoder.t/0","doc":"","ref":"Xav.Decoder.html#t:t/0"},{"type":"module","title":"Xav.Frame","doc":"Audio/video frame.","ref":"Xav.Frame.html"},{"type":"function","title":"Xav.Frame.new/4","doc":"","ref":"Xav.Frame.html#new/4"},{"type":"function","title":"Xav.Frame.new/5","doc":"Creates a new audio/video frame.","ref":"Xav.Frame.html#new/5"},{"type":"function","title":"Xav.Frame.to_nx/1","doc":"Converts a frame to an Nx tensor.","ref":"Xav.Frame.html#to_nx/1"},{"type":"type","title":"Xav.Frame.audio_format/0","doc":"Possible audio samples formats.","ref":"Xav.Frame.html#t:audio_format/0"},{"type":"type","title":"Xav.Frame.format/0","doc":"","ref":"Xav.Frame.html#t:format/0"},{"type":"type","title":"Xav.Frame.t/0","doc":"","ref":"Xav.Frame.html#t:t/0"},{"type":"type","title":"Xav.Frame.video_format/0","doc":"Possible video frame formats.\n\nCurrently, only RGB is supported.","ref":"Xav.Frame.html#t:video_format/0"},{"type":"module","title":"Xav.Reader","doc":"Audio/video file reader.","ref":"Xav.Reader.html"},{"type":"function","title":"Xav.Reader.new/2","doc":"Creates a new audio/video reader.\n\nBoth reading from a file and from a video camera are supported.\nIn case of using a video camera, the v4l2 driver is required, and FPS are\nlocked to 10.\n\nMicrophone input is not supported.\n\n`opts` can be used to specify desired output parameters.\nVideo frames are always returned in RGB format. This setting cannot be changed.\nAudio samples are always in the packed form.\nSee `Xav.Decoder.new/2` for more information.","ref":"Xav.Reader.html#new/2"},{"type":"function","title":"Xav.Reader.new!/2","doc":"The same as new/1 but raises on error.","ref":"Xav.Reader.html#new!/2"},{"type":"function","title":"Xav.Reader.next_frame/1","doc":"Reads and decodes the next frame.","ref":"Xav.Reader.html#next_frame/1"},{"type":"function","title":"Xav.Reader.seek/2","doc":"Seeks the reader to the given time in seconds","ref":"Xav.Reader.html#seek/2"},{"type":"function","title":"Xav.Reader.stream!/2","doc":"Creates a new reader stream.","ref":"Xav.Reader.html#stream!/2"},{"type":"type","title":"Xav.Reader.opts/0","doc":"Reader options.\n\n* `read` - determines which stream to read from a file.\nDefaults to `:video`.\n* `device?` - determines whether path points to the camera. Defaults to `false`.","ref":"Xav.Reader.html#t:opts/0"},{"type":"type","title":"Xav.Reader.t/0","doc":"","ref":"Xav.Reader.html#t:t/0"},{"type":"extras","title":"Xav","doc":"# Xav\n\n[![Hex.pm](https://img.shields.io/hexpm/v/xav.svg)](https://hex.pm/packages/xav)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](https://hexdocs.pm/xav)\n[![CI](https://img.shields.io/github/actions/workflow/status/elixir-webrtc/xav/ci.yml?logo=github&label=CI)](https://github.com/elixir-webrtc/xav/actions/workflows/ci.yml)\n[![codecov](https://codecov.io/gh/elixir-webrtc/xav/graph/badge.svg?token=2AG2acRhOf)](https://codecov.io/gh/elixir-webrtc/xav)\n\nElixir wrapper over FFmpeg for reading audio and video files.\n\nSee an interview with FFmpeg enthusiast:  https://youtu.be/9kaIXkImCAM","ref":"readme.html"},{"type":"extras","title":"Installation - Xav","doc":"Make sure you have installed FFMpeg (ver. 4.x - 7.x) development packages on your system\n(see [here](INSTALL.md) for installation one-liners) and add Xav to the list of your dependencies:\n\n```elixir\ndef deps do\n  [\n    {:xav, \"~> 0.7.0\"},\n    # Add Nx if you want to have Xav.Frame.to_nx/1\n    {:nx, \">= 0.0.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Xav","doc":"Decode\n\n```elixir\ndecoder = Xav.Decoder.new(:vp8)\n{:ok, %Xav.Frame{} = frame} = Xav.Decoder.decode(decoder, <<\"somebinary\">>)\n```\n\nDecode with audio resampling\n\n```elixir\ndecoder = Xav.Decoder.new(:opus, out_format: :f32, out_sample_rate: 16_000)\n{:ok, %Xav.Frame{} = frame} = Xav.Decoder.decode(decoder, <<\"somebinary\">>)\n```\n\nRead from a file:\n\n```elixir\nr = Xav.Reader.new!(\"./some_mp4_file.mp4\")\n{:ok, %Xav.Frame{} = frame} = Xav.Reader.next_frame(r)\ntensor = Xav.Frame.to_nx(frame)\nKino.Image.new(tensor)\n```\n\nRead from a camera:\n\n```elixir\nr = Xav.Reader.new!(\"/dev/video0\", device?: true)\n{:ok, %Xav.Frame{} = frame} = Xav.Reader.next_frame(r)\ntensor = Xav.Frame.to_nx(frame)\nKino.Image.new(tensor)\n```\n\nSpeech to text:\n\n```elixir\n{:ok, whisper} = Bumblebee.load_model({:hf, \"openai/whisper-tiny\"})\n{:ok, featurizer} = Bumblebee.load_featurizer({:hf, \"openai/whisper-tiny\"})\n{:ok, tokenizer} = Bumblebee.load_tokenizer({:hf, \"openai/whisper-tiny\"})\n{:ok, generation_config} = Bumblebee.load_generation_config({:hf, \"openai/whisper-tiny\"})\n\nserving =\n  Bumblebee.Audio.speech_to_text_whisper(whisper, featurizer, tokenizer, generation_config,\n    defn_options: [compiler: EXLA]\n  )\n\n# Read a couple of frames.\n# See https://hexdocs.pm/bumblebee/Bumblebee.Audio.WhisperFeaturizer.html for default sampling rate.\nframes =\n    Xav.Reader.stream!(\"sample.mp3\", read: :audio, out_format: :f32, out_channels: 1, out_sample_rate: 16_000)\n    |> Stream.take(200)\n    |> Enum.map(fn frame -> Xav.Frame.to_nx(frame) end)\n\nbatch = Nx.Batch.concatenate(frames)\nbatch = Nx.Defn.jit_apply(&Function.identity/1, [batch])\nNx.Serving.run(serving, batch) \n```","ref":"readme.html#usage"},{"type":"extras","title":"Development - Xav","doc":"To make `clangd` aware of the header files used in your project, you can create a `compile_commands.json` file. \n`clangd` uses this file to know the compiler flags, include paths, and other compilation options for each source file.","ref":"readme.html#development"},{"type":"extras","title":"Install bear - Xav","doc":"The easiest way to generate `compile_commands.json` from a Makefile is to use the `bear` tool. `bear` is a tool that records the compiler calls during a build and creates the `compile_commands.json` file.\n\nYou can install `bear` with your package manager:\n\n- __macOS__: brew install bear\n- __Ubuntu/Debian__: sudo apt install bear\n- __Fedora__: sudo dnf install bear","ref":"readme.html#install-bear"},{"type":"extras","title":"Generate compile_commands.json - Xav","doc":"After installing bear, you can run it alongside your make command to capture the necessary information.\n\n```bash\nbear -- mix compile\n```","ref":"readme.html#generate-compile_commands-json"},{"type":"extras","title":"INSTALL","doc":"Xav requires FFmpeg development packages to be installed on your system.\nYou can install them with one of the following one-liners.\n\nOn some platforms, we use pkg-config to determine ffmpeg's include and lib directories.\n\n**Fedora**\n\n```bash\ndnf install pkg-config ffmpeg-devel ffmpeg-libs\n```\n\n**Ubuntu**\n\n```bash\napt install libavcodec-dev libavformat-dev libavutil-dev libswscale-dev libavdevice-dev\n```\n\n**MacOS x86_64**\n\n```bash\nbrew install ffmpeg\n```\n\n**MacOS arm64**\n\n```bash\nbrew install pkg-config ffmpeg\n```\n\n**Windows**\n\nWindows is not supported but PRs are welcomed.","ref":"install.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}